estimatedHeight property
Seed height used for the very first layout, before the header has been measured once.
Implementation
final double estimatedHeight;
Seed height used for the very first layout, before the header has been measured once.
final double estimatedHeight;