GridDataRow<T extends DataGridRow> class final

A slot rendering the row identified by rowId (an id from DataGridState.displayOrder / a key into DataGridState.rowsById).

Inheritance

Constructors

GridDataRow(double rowId)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
rowId double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited