ShiftSelectCellEvent class
Appends a cell to the focused-cells path (Shift+click). If the cell is already the last in the path, this is a no-op. Preserves all previously focused cells.
- Inheritance
-
- Object
- DataGridEvent
- ShiftSelectCellEvent
Constructors
- ShiftSelectCellEvent({required double rowId, required int columnId})
Properties
Methods
-
apply<
T extends DataGridRow> (EventContext< T> context) → DataGridState<T> ? -
Apply this event's transformation to the state.
Returns the new state, or null if no state change should occur.
Can return a Future for async operations.
override
-
loadingMessage(
) → String? -
Custom loading message
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldShowLoading(
DataGridState< DataGridRow> state) → bool -
Whether this event should show loading indicator for large datasets
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited