SortCompleteEvent<T extends DataGridRow> class

Internal event dispatched when an async sort operation completes.

Inheritance

Constructors

SortCompleteEvent({required DataGridState<T> newState})

Properties

hashCode → int
The hash code for this object.
no setterinherited
newState → DataGridState<T>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

apply<R extends DataGridRow>(EventContext<R> context) → DataGridState<T>?
Apply this event's transformation to the state. Returns the new state, or null if no state change should occur. Can return a Future for async operations.
override
loadingMessage() → String?
Custom loading message
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldShowLoading(DataGridState<DataGridRow> state) → bool
Whether this event should show loading indicator for large datasets
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited