SelectionState class abstract

Row and cell selection state.

Available extensions
Annotations
  • @freezed

Constructors

SelectionState({required Set<double> selectedRowIds, double? focusedRowId, @Default.new([]) List<String> focusedCells, required SelectionMode mode})
const
factory
SelectionState.initial()
Creates an initial selection state with no selection.
factory

Properties

activeCellId String?
The active/cursor cell (last in path), or null if no cells are focused.
no setter
anchorCellId String?
The anchor cell (first in path), or null if no cells are focused.
no setter
copyWith → $SelectionStateCopyWith<SelectionState>
Create a copy of SelectionState with the given fields replaced by the non-null parameter values.
no setterinherited
focusedCells List<String>
no setterinherited
focusedRowId double?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
mode SelectionMode
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedRowIds Set<double>
no setterinherited

Methods

isActiveCellId(String cellId) bool
Returns true if cellId is the active (last) cell in the focused path.
isCellFocused(String cellId) bool
Returns true if cellId is anywhere in the focused cells path.
isRowSelected(double rowId) bool
Returns true if the row with rowId is currently selected.
map<TResult extends Object?>(TResult $default(_SelectionState value)) → TResult

Available on SelectionState, provided by the SelectionStatePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_SelectionState value)?) → TResult?

Available on SelectionState, provided by the SelectionStatePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_SelectionState value)?, {required TResult orElse()}) → TResult

Available on SelectionState, provided by the SelectionStatePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(Set<double> selectedRowIds, double? focusedRowId, List<String> focusedCells, SelectionMode mode)?, {required TResult orElse()}) → TResult

Available on SelectionState, provided by the SelectionStatePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(Set<double> selectedRowIds, double? focusedRowId, List<String> focusedCells, SelectionMode mode)) → TResult

Available on SelectionState, provided by the SelectionStatePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(Set<double> selectedRowIds, double? focusedRowId, List<String> focusedCells, SelectionMode mode)?) → TResult?

Available on SelectionState, provided by the SelectionStatePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited