VisibleRowRange class

The (buffered) window of row indices a quadrant should build, as [firstRow, lastRow).

Constructors

VisibleRowRange(int firstRow, int lastRow)
const

Properties

firstRow int
final
hashCode int
The hash code for this object.
no setteroverride
lastRow int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override