GridUnpinnedQuadrant<T extends DataGridRow> class

Renders the scrollable (unpinned) quadrant of the custom layout grid.

Listens to both hOffset and vOffset via a merged Listenable and virtualizes rows and columns so only visible cells (plus cacheExtent buffer) are built.

Inheritance

Constructors

GridUnpinnedQuadrant({Key? key, required List<DataGridColumn<T>> columns, required List<int> unpinnedIndices, required double pinnedWidth, required double viewportWidth, required double viewportHeight, required List<double> displayOrder, required Map<double, T> rowsById, required int rowCount, required double rowHeight, required double cacheExtent, required ValueNotifier<double> hOffset, required ValueNotifier<double> vOffset})
const

Properties

cacheExtent double
final
columns List<DataGridColumn<T>>
final
displayOrder List<double>
final
hashCode int
The hash code for this object.
no setterinherited
hOffset ValueNotifier<double>
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
pinnedWidth double
final
rowCount int
final
rowHeight double
final
rowsById Map<double, T>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unpinnedIndices List<int>
final
viewportHeight double
final
viewportWidth double
final
vOffset ValueNotifier<double>
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited