CellValueChange class

Constructors

CellValueChange({required double rowId, required int columnId, required dynamic value, CellValueChangeSource source = CellValueChangeSource.programmatic})
const

Properties

cellId String
no setter
columnId int
final
hashCode int
The hash code for this object.
no setteroverride
rowId double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source CellValueChangeSource
final
value → dynamic
final

Methods

affectsCell(double rowId, int columnId) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override