GridGroupHeaderRow<T extends DataGridRow> class
final
A slot rendering a collapsible group header band.
- Inheritance
-
- Object
- GridDisplayRow<
T> - GridGroupHeaderRow
Constructors
Properties
- columnId → int
-
The id of the column rows are grouped by.
final
- columnTitle → String
-
Display title of the grouped column.
final
- displayLabel → String
-
Formatted label shown in the band.
final
- groupKey → String
-
Deterministic key, e.g.
'$columnId:$value'. Passed toToggleGroupExpansionEventand used as theGroupState.expandedGroupskey.final - hashCode → int
-
The hash code for this object.
no setterinherited
- isExpanded → bool
-
Whether this group's rows are currently shown below the band.
final
- rowCount → int
-
Number of rows in this group, regardless of expansion state.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → dynamic
-
Raw group value shared by every row in this group.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited