SelectionState class abstract
Row and cell selection state.
- Available extensions
- Annotations
-
- @freezed
Constructors
-
SelectionState({required Set<
double> selectedRowIds, double? focusedRowId, @Default.new([]) List<String> focusedCells, required SelectionMode mode}) -
constfactory
- SelectionState.initial()
-
Creates an initial selection state with no selection.
factory
Properties
- activeCellId → String?
-
The active/cursor cell (last in path), or
nullif no cells are focused.no setter - anchorCellId → String?
-
The anchor cell (first in path), or
nullif no cells are focused.no setter -
copyWith
→ $SelectionStateCopyWith<
SelectionState> -
Create a copy of SelectionState
with the given fields replaced by the non-null parameter values.
no setterinherited
-
focusedCells
→ List<
String> -
no setterinherited
- focusedRowId → double?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- mode → SelectionMode
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
selectedRowIds
→ Set<
double> -
no setterinherited
Methods
-
isActiveCellId(
String cellId) → bool -
Returns
trueifcellIdis the active (last) cell in the focused path. -
isCellFocused(
String cellId) → bool -
Returns
trueifcellIdis anywhere in the focused cells path. -
isRowSelected(
double rowId) → bool -
Returns
trueif the row withrowIdis currently selected. -
map<
TResult extends Object?> (TResult $default(_SelectionState value)) → TResult -
Available on SelectionState, provided by the SelectionStatePatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_SelectionState value)?) → TResult? -
Available on SelectionState, provided by the SelectionStatePatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_SelectionState value)?, {required TResult orElse()}) → TResult -
Available on SelectionState, provided by the SelectionStatePatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(Set< double> selectedRowIds, double? focusedRowId, List<String> focusedCells, SelectionMode mode)?, {required TResult orElse()}) → TResult -
Available on SelectionState, provided by the SelectionStatePatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(Set< double> selectedRowIds, double? focusedRowId, List<String> focusedCells, SelectionMode mode)) → TResult -
Available on SelectionState, provided by the SelectionStatePatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(Set< double> selectedRowIds, double? focusedRowId, List<String> focusedCells, SelectionMode mode)?) → TResult? -
Available on SelectionState, provided by the SelectionStatePatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited